instrumenttools.Xylophone
=========================

.. inheritance-diagram:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone
   :private-bases:

.. autoclass:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.default_instrument_name

   .. note:: Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.default_short_instrument_name

   .. note:: Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.effective_context

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.format

   .. note:: Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.interval_of_transposition

   .. note:: Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.is_primary_instrument

   .. note:: Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.is_secondary_instrument

   .. note:: Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.is_transposing

   .. note:: Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.start_component

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.target_context

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.traditional_pitch_range

   .. note:: Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.all_clefs

   .. note:: Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.instrument_name

   .. note:: Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.instrument_name_markup

   .. note:: Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.pitch_range

   .. note:: Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.primary_clefs

   .. note:: Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.short_instrument_name

   .. note:: Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.short_instrument_name_markup

   .. note:: Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.sounding_pitch_of_fingered_middle_c

   .. note:: Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.attach

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.detach

   .. note:: Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.get_default_performer_name

   .. note:: Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.get_performer_names

   .. note:: Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__call__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__delattr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__eq__

   .. note:: Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__hash__

   .. note:: Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__ne__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__repr__

   .. note:: Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__str__

   .. note:: Inherited from `__builtin__.object`
